def file_ext(filename):
	import os
	ext = os.path.splitext(filename)[1]
	print ext

def is_ext(filename, ext):
	import os
	file_ext = os.path.splitext(filename)[1]
	if ext == file_ext:
		print "Files match"
	else:
		print "Files don't match"

def hello():
	print "Saqib is awesome"


from setuptools import setup

setup(name='CarvePie',
      version='0.2',
      description='Python helper for python ninja',
      url='http://github.com/saqirzzq/CarvePy',
      author='Saqib Razzaq',
      author_email='saqi.cb@gmail.com',
      license='MIT',
      packages=['CarvePie'],
      zip_safe=False)